@@ -4,14 +4,16 @@
 
 # Setup virtualenv, virtualenvwrapper (for bash only);
 
-echo "export VENV_NAME=$VENV_NAME" >> $HOME/.profile
-cat <<'EOF' >> $HOME/.profile
-if [ -n "$BASH_VERSION" ]; then 
-  export WORKON_HOME=~/.venvs
-  . /usr/share/virtualenvwrapper/virtualenvwrapper.sh
-  workon $VENV_NAME
-fi
+if [ -n "$VENV_NAME" ]; then
+  echo "export VENV_NAME=$VENV_NAME" >> $HOME/.profile
+  cat <<'EOF' >> $HOME/.profile
+  if [ -n "$BASH_VERSION" ]; then 
+    export WORKON_HOME=~/.venvs
+    . /usr/share/virtualenvwrapper/virtualenvwrapper.sh
+    workon $VENV_NAME
+  fi
 EOF
+fi
 
 # Setup environment
 echo "if [ -z \"\$DISPLAY\" ]; then export DISPLAY=:100; fi" >> $HOME/.profile
@@ -53,10 +55,10 @@ EOF
 
 # User installs and config
 sh -l -c "
-./travis/createTestSshKey.sh;
-./travis/createTestGpgKey.sh;
-./travis/configurePip.sh;
-./travis/setupTestGit.sh
+./scripts/createTestSshKey.sh;
+./scripts/createTestGpgKey.sh;
+./scripts/configurePip.sh;
+./scripts/setupTestGit.sh
 "
 
 
